@@ -147,21 +147,18 @@ setMethodS3("createMonocellCdf", "AffymetrixCdfFile", function(this, chipType=ge
     path <- filePath("annotationData", "chipTypes", mainChipType, expandLinks="any");
   }
 
-  # Write to a temporary file first, and rename it when we know i's complete
   name <- paste(c(chipType, tags), collapse=sep);
-  dest <- sprintf("%s.CDF", name);
-  dest <- Arguments$getWritablePathname(dest, path=path);
-  dest <- AffymetrixFile$renameToUpperCaseExt(dest);
-  dest <- Arguments$getWritablePathname(dest, mustNotExist=TRUE);
+  filename <- sprintf("%s.CDF", name);
+  pathname <- Arguments$getWritablePathname(filename, path=path);
+  pathname <- AffymetrixFile$renameToUpperCaseExt(pathname);
+  pathname <- Arguments$getWritablePathname(pathname, mustNotExist=TRUE);
 
-  tmpDest <- sprintf("%s.tmp", dest);
-  tmpDest <- Arguments$getWritablePathname(tmpDest, mustNotExist=TRUE);
-
-  verbose && cat(verbose, "Output pathname (temporary): ", tmpDest);
+  # Write to a temporary file first, and rename it when we know i's complete
+  pathnameT <- pushTemporaryFile(pathname, verbose=verbose);
 
   # Assure source and destination is not identical
-  if (identical(src, tmpDest)) {
-    throw("Cannot not create CDF file. Destination is same as source: ", src);
+  if (identical(src, pathnameT)) {
+    throw("Cannot create CDF file. Destination is same as source: ", src);
   }
 
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -299,7 +296,7 @@ setMethodS3("createMonocellCdf", "AffymetrixCdfFile", function(this, chipType=ge
   verbose && print(verbose, gc);
 
   # Open output connection
-  con <- file(tmpDest, open = "wb");
+  con <- file(pathnameT, open = "wb");
   on.exit({
     if (!is.null(con))
       close(con);
@@ -466,8 +463,8 @@ setMethodS3("createMonocellCdf", "AffymetrixCdfFile", function(this, chipType=ge
   con <- NULL;
 
   verbose && cat(verbose, "Temporary CDF file created:");
-  verbose && cat(verbose, "Output pathname: ", tmpDest);
-  verbose && print(verbose, file.info(tmpDest));
+  verbose && cat(verbose, "Output pathname: ", pathnameT);
+  verbose && print(verbose, file.info(pathnameT));
 
   # Garbage collect
   gc <- gc();
@@ -480,7 +477,7 @@ setMethodS3("createMonocellCdf", "AffymetrixCdfFile", function(this, chipType=ge
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   verbose && enter(verbose, "Verifying the written CDF");
   # Checking header
-  header <- readCdfHeader(tmpDest);
+  header <- readCdfHeader(pathnameT);
   if ((header$nrows != nrows) || (header$ncols != ncols)) {
     throw(sprintf("Failed to create a valid mono-cell CDF: The dimension of the written CDF does not match the intended one: (%d,%d) != (%d,%d)", header$nrows, header$ncols, nrows, ncols));
   }
@@ -494,7 +491,7 @@ setMethodS3("createMonocellCdf", "AffymetrixCdfFile", function(this, chipType=ge
     verbose && printf(verbose, "Chunk %d of %d\n", kk, nbrOfChunks);
     from <- (kk-1)*chunkSize+1;
     to <- min(from+chunkSize, nbrOfUnits);
-    cells <- readCdfCellIndices(tmpDest, units=from:to);
+    cells <- readCdfCellIndices(pathnameT, units=from:to);
     cells <- unlist(cells, use.names=FALSE);
     cells <- diff(cells);
     cells <- unique(cells);
@@ -510,17 +507,17 @@ setMethodS3("createMonocellCdf", "AffymetrixCdfFile", function(this, chipType=ge
   gc <- gc();
   verbose && print(verbose, gc);
 
-  verbose && enter(verbose, "Renaming the temporary file");
-  res <- file.rename(tmpDest, dest);
-  verbose && cat(verbose, "Result: ", res);
-  verbose && cat(verbose, "File pathname: ", dest);
-  verbose && print(verbose, file.info(dest));
+  # Renaming temporary file
+  pathname <- popTemporaryFile(pathnameT, verbose=verbose);
+
+  verbose && cat(verbose, "File pathname: ", pathname);
+  verbose && print(verbose, file.info(pathname));
   verbose && exit(verbose);
 
   verbose && exit(verbose);
 
   # Return an AffymetrixCdfFile object for the new CDF
-  newInstance(this, dest);
+  newInstance(this, pathname);
 }, private=TRUE) # createMonocellCdf()
 
 
@@ -549,7 +546,7 @@ setMethodS3("getMonocellCdf", "AffymetrixCdfFile", function(this, ..., verbose=F
 
   # First, try to locate an existing monocell CDF
   verbose && enter(verbose, "Locating monocell CDF");
-  pathname <- findByChipType(this, chipType=chipType, ...);
+  pathname <- findByChipType(this, chipType=chipType, ..., verbose=less(verbose,20));
   verbose && cat(verbose, "Pathname: ", pathname);
   verbose && exit(verbose);
 
